# Copyright 2018 Calculation Consulting [calculationconsulting.com]
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from __future__ import division, print_function

__name__ = "weightwatcher"
__version__ = "0.5.7"
__license__ = "Apache License, Version 2.0"
__description__ = "Diagnostic Tool for Deep Neural Networks"
__url__ = "https://calculationconsulting.com/"
__author__ = "Calculation Consulting"
__email__ = "info@calculationconsulting.com"
__copyright__ = "Calculation Consulting"

__all__ = ["__name__", "__version__", "__license__", "__description__",
          "__url__", "__author__", "__email__", "__copyright__"]

from .constants import *
from .weightwatcher import WeightWatcher

